View source: R/NoviceDeveloperResources2.R
| sortedInputForCheckBuildInstallSourcePackage | R Documentation |
compute a list of packages in the correct order to input to checkBuildInstallSourcePackage()
sortedInputForCheckBuildInstallSourcePackage(retrieve, burd)
retrieve |
return value of retrieveLeafNodes() |
burd |
return value of bottomUpRecursiveDriver() |
returns a list of packages in the correct order to input to checkBuildInstallSourcePackage()
## Not run:
# you need to specify dir, packs that are on your own computer !!
dir1<-"~/personal/hearts/hearts_card_game_bayesian_inference"
dir2<-"packages/inference_packages/inference_packages/"
packs<-c("cardUtils","clickableImageMap","editDriver",
"heartsCIM","iterationDriver","logos","playOneTrick",
"playWholeHandDriverPassParams","probTab","relaxDriver")
master<-PackageDependencies(sprintf("%s/%s",dir1,dir2),packs,vector("list",length(packs)),1,TRUE)
l<-retrieveNamespace(sprintf("%s/%s",dir1,dir2),packs)
burd<-bottomUpRecursiveDriver(l,c("iterationDriver"),TRUE)
retrieve<-retrieveLeafNodes(master)
s<-sortedInputForCheckBuildInstallSourcePackage(retrieve,burd)
## End(Not run)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.